@@ -2,11 +2,10 @@
 #
 # The PyMca X-Ray Fluorescence Toolkit
 #
-# Copyright (c) 2004-2022 European Synchrotron Radiation Facility
+# Copyright (c) 2004-2023 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
 # the ESRF.
-#
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
 # in the Software without restriction, including without limitation the rights
@@ -64,7 +63,6 @@ class MaterialEditor(qt.QWidget):
             else:
                 self.graphDialog = None
                 self.graph = graph
-
         self.__toolMode = toolmode
         self.build(comments, height)
 
@@ -114,6 +112,7 @@ class MaterialEditor(qt.QWidget):
                                         position=True)
                 self.graph._togglePointsSignal()
                 self.graph.enableOwnSave(True)
+                self.graph.setDataMargins(0, 0, 0.025, 0.025)
             layout.addWidget(self.materialGUI)
             layout.addWidget(self.graph)
         else:
@@ -144,7 +143,7 @@ class MaterialEditor(qt.QWidget):
                 Elements.getMaterialMassAttenuationCoefficients(compoundList,
                                                                 compoundFraction,
                                                                 energy = 10.0)
-            except:
+            except Exception:
                 #no message?
                 error = 1
                 del Elements.Material[material]
@@ -203,7 +202,7 @@ class MaterialEditor(qt.QWidget):
             self.graph.setGraphTitle(ddict['Comment'])
             if self.graphDialog is not None:
                 self.graphDialog.exec()
-        except:
+        except Exception:
             msg=qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setInformativeText(str(sys.exc_info()[1]))
@@ -252,7 +251,7 @@ class MaterialEditor(qt.QWidget):
             self.graph.setGraphTitle(ddict['Comment'])
             if self.graphDialog is not None:
                 self.graphDialog.exec()
-        except:
+        except Exception:
             msg=qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setInformativeText(str(sys.exc_info()[1]))
@@ -264,6 +263,12 @@ class MaterialEditor(qt.QWidget):
             self.graph.close()
         qt.QWidget.closeEvent(self, event)
 
+    def show(self):
+        if self.graph is not None:
+            if self.graph.isHidden():
+                self.graph.show()
+        qt.QWidget.show(self)
+
 class MaterialComboBox(qt.QComboBox):
     sigMaterialComboBoxSignal = qt.pyqtSignal(object)
     def __init__(self,parent=None,name = None,fl = 0,
@@ -332,7 +337,7 @@ class MaterialComboBox(qt.QComboBox):
                                 "Hint: You can use _%s_" % text)
                     msg.exec()
                     msg = qt.QMessageBox.No
-                except:
+                except Exception:
                     msg=qt.QMessageBox.information( self, "Invalid Material %s" % str(qstring),
                                           "The material %s is not a valid Formula " \
                                           "nor a valid Material.\n" \
@@ -392,7 +397,12 @@ class MaterialComboBox(qt.QComboBox):
 class MaterialValidator(qt.QValidator):
     def __init__(self, *var):
         qt.QValidator.__init__(self, *var)
-        self.Valid = self.Acceptable
+        if hasattr(self, "Acceptable"):
+            self.Valid = self.Acceptable
+        else:
+            self.Valid = qt.QValidator.State.Acceptable
+        if not hasattr(self, "Invalid"):
+            self.Invalid = qt.QValidator.State.Invalid
 
     def fixup(self, qstring):
         if qstring is None:
@@ -414,7 +424,7 @@ class MaterialValidator(qt.QValidator):
             # this test is needed even if pyflakes complains!
             float(text)
             return (self.Invalid, pos)
-        except:
+        except Exception:
             pass
         if text.endswith(' '):
             return (self.Invalid, pos)
@@ -726,12 +736,12 @@ class MaterialGUI(qt.QWidget):
             self.__nameLine.setText("%s" % self._current['Comment'])
             try:
                 self.__densityLine.setText("%.5g" % self._current['Density'])
-            except:
+            except Exception:
                 self.__densityLine.setText("")
             if 'Thickness' in self._current.keys():
                 try:
                     self.__thicknessLine.setText("%.5g" % self._current['Thickness'])
-                except:
+                except Exception:
                     self.__thicknessLine.setText("")
         if type(self._current['CompoundList']) != type([]):
             self._current['CompoundList'] = [self._current['CompoundList']]
@@ -788,7 +798,7 @@ class MaterialGUI(qt.QWidget):
             if len(text):
                 value = float(str(qstring))
                 self._current['Density'] = value
-        except:
+        except Exception:
             if silent:
                 return
             msg=qt.QMessageBox(self.__densityLine)
@@ -804,7 +814,7 @@ class MaterialGUI(qt.QWidget):
             if len(text):
                 value = float(text)
                 self._current['Thickness'] = value
-        except:
+        except Exception:
             if silent:
                 return
             msg=qt.QMessageBox(self.__thicknessLine)
@@ -901,7 +911,7 @@ class MaterialGUI(qt.QWidget):
         else:
             try:
                 float(str(qstring))
-            except:
+            except Exception:
                 msg=qt.QMessageBox(self.__table)
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("Invalid Float")
@@ -954,7 +964,7 @@ class MaterialGUI(qt.QWidget):
         else:
             try:
                 float(str(qstring))
-            except:
+            except Exception:
                 msg=qt.QMessageBox(self.__table)
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("Invalid Float")
