@@ -2,10 +2,10 @@
 #
 # The PyMca X-Ray Fluorescence Toolkit
 #
-# Copyright (c) 2020 European Synchrotron Radiation Facility
+# Copyright (c) 2020-2023 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -38,7 +38,7 @@ import numpy
 import traceback
 from PyMca5.PyMcaGui import PyMcaQt as qt
 from PyMca5.PyMcaCore import PyMcaDirs
-from PyMca5.PyMcaGui import PyMcaFileDialogs
+from PyMca5.PyMcaGui.io import PyMcaFileDialogs
 from PyMca5.PyMcaIO import specfilewrapper as specfile
 from PyMca5.PyMcaIO import ArraySave
 
@@ -146,7 +146,7 @@ class TransmissionTableEditor(qt.QWidget):
                     self.loadTransmissionTable(filename)
                     self.inputDir = os.path.dirname(filename)
                     PyMcaDirs.inputDir = self.inputDir
-                except:
+                except Exception:
                     msg = qt.QMessageBox(self)
                     msg.setIcon(qt.QMessageBox.Critical)
                     msg.setText("Error transmission table: %s" % (sys.exc_info()[1]))
@@ -218,7 +218,7 @@ class TransmissionTableEditor(qt.QWidget):
         try:
             self.outputDir  = os.path.dirname(outputFile)
             PyMcaDirs.outputDir = os.path.dirname(outputFile)
-        except:
+        except Exception:
             self.outputDir  = "."
         if not outputFile.endswith('.csv'):
             outputFile += '.csv'
@@ -296,7 +296,7 @@ class TransmissionTableEditor(qt.QWidget):
         try:
             self._validateDict(ddict)
             self._transmissionTable = ddict
-        except:
+        except Exception:
             msg=qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setInformativeText(str(sys.exc_info()[1]))
