@@ -1,8 +1,8 @@
 #/*##########################################################################
-# Copyright (C) 2004-2020 V.A. Sole, European Synchrotron Radiation Facility
+# Copyright (C) 2004-2023 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -23,7 +23,7 @@
 # THE SOFTWARE.
 #
 #############################################################################*/
-__author__ = "V.A. Sole - ESRF Data Analysis"
+__author__ = "V.A. Sole - ESRF"
 __contact__ = "sole@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
@@ -39,6 +39,7 @@ else:
 
 QTVERSION = qt.qVersion()
 
+from PyMca5.PyMcaGui.io import PyMcaFileDialogs
 from PyMca5.PyMcaCore import PyMcaDirs
 from PyMca5.PyMcaIO import ConfigDict
 from PyMca5.PyMcaGui.io import ConfigurationFileDialogs
@@ -217,24 +218,16 @@ class McaROIWidget(qt.QWidget):
             self.roiDir = PyMcaDirs.outputDir
         elif not os.path.isdir(self.roiDir):
             self.roiDir = PyMcaDirs.outputDir
-        outfile = qt.QFileDialog(self)
-        if hasattr(outfile, "setFilters"):
-            outfile.setFilter('PyMca  *.ini')
-        else:
-            outfile.setNameFilters(['PyMca  *.ini', 'All *'])
-        outfile.setFileMode(outfile.AnyFile)
-        outfile.setAcceptMode(qt.QFileDialog.AcceptSave)
-        outfile.setDirectory(self.roiDir)
-        ret = outfile.exec()
-        if not ret:
-            outfile.close()
-            del outfile
+
+        outputFile = PyMcaFileDialogs.getFileList(self, filetypelist=['PyMca  *.ini', 'All *'],
+                                                  message="Provide output file", currentdir=self.roiDir,
+                                                  mode="SAVE", getfilter=False, single=False, currentfilter=None, native=None)
+        if not len(outputFile):
             return
-        # pyflakes bug http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=666494
-        outputFile = qt.safe_str(outfile.selectedFiles()[0])
+
+        outputFile = outputFile[0]
         extension = ".ini"
-        outfile.close()
-        del outfile
+
         if len(outputFile) < len(extension[:]):
             outputFile += extension[:]
         elif outputFile[-4:] != extension[:]:
@@ -539,7 +532,7 @@ class McaROITable(qt.QTableWidget):
         text = str(item.text())
         try:
             value = float(text)
-        except:
+        except Exception:
             # recover old value
             oldItem = self.item(row, 0)
             if oldItem is None:
@@ -661,7 +654,7 @@ class MyQTableWidgetItem(qt.QTableWidgetItem):
     def __lt__(self, other):
         try:
             return float(self.text()) < float(other.text())
-        except:
+        except Exception:
             return self.text() < other.text()
 
 if __name__ == '__main__':
