@@ -1,5 +1,5 @@
 # /*#########################################################################
-# Copyright (C) 2004-2022 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2023 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
 # the ESRF.
@@ -42,6 +42,7 @@ import os
 from PyMca5.PyMcaMath.PyMcaSciPy.signal.median import medfilt2d
 
 from PyMca5.PyMcaGui import PyMcaQt as qt
+from PyMca5.PyMcaGui.io import PyMcaFileDialogs
 if hasattr(qt, "QString"):
     QString = qt.QString
 else:
@@ -69,6 +70,7 @@ from silx.gui.plot import PlotToolButtons
 from silx.gui.plot.MaskToolsWidget import MaskToolsWidget, MaskToolsDockWidget
 from silx.gui.plot.AlphaSlider import NamedImageAlphaSlider
 from silx.gui.plot.Profile import ProfileToolBar
+from silx.gui.plot.tools.profile.manager import ProfileWindow
 
 from silx.gui import icons
 
@@ -110,6 +112,19 @@ def convertToRowAndColumn(x, y, shape,
         r = int(r)
     return r, c
 
+class MyProfileWindow(ProfileWindow):
+
+    def createPlot1D(self, parent, backend):
+        from PyMca5.PyMcaGui.pymca.SilxScanWindow import ScanWindow as PlotWindow
+        plot = PlotWindow(parent, backend=backend)
+        plot.setDataMargins(yMinMargin=0.1, yMaxMargin=0.1)
+        plot.setGraphYLabel('Profile')
+        plot.setGraphXLabel('')
+        # do not overwrite the title by the legend
+        plot.sigActiveCurveChanged.disconnect(plot._updateGraphTitle)
+        positionInfo = plot.getPositionInfoWidget()
+        positionInfo.setSnappingMode(positionInfo.SNAPPING_CURVE)
+        return plot
 
 class MyMaskToolsWidget(MaskToolsWidget):
     """Backport of the setSelectionMask behavior implemented in silx 0.6.0,
@@ -269,41 +284,28 @@ class SaveImageListAction(qt.QAction):
         else:
             # folder deleted, reset
             initdir = PyMcaDirs.outputDir
-        filedialog = qt.QFileDialog(self.maskImageWidget)
-        filedialog.setFileMode(filedialog.AnyFile)
-        filedialog.setAcceptMode(qt.QFileDialog.AcceptSave)
-        filedialog.setWindowIcon(qt.QIcon(qt.QPixmap(IconDict["gioconda16"])))
+
         formatlist = ["TIFF Files *.tif",
                       "ASCII Files *.dat",
                       "EDF Files *.edf",
                       'CSV(, separated) Files *.csv',
                       'CSV(; separated) Files *.csv',
                       'CSV(tab separated) Files *.csv']
-        if hasattr(qt, "QStringList"):
-            strlist = qt.QStringList()
-        else:
-            strlist = []
-        for f in formatlist:
-            strlist.append(f)
-        saveFilter = formatlist[0]
-        if hasattr(filedialog, "setFilters"):
-            filedialog.setFilters(strlist)
-            filedialog.selectFilter(saveFilter)
-        else:
-            filedialog.setNameFilters(strlist)
-            filedialog.selectNameFilter(saveFilter)
-        filedialog.setDirectory(initdir)
-        ret = filedialog.exec()
-        if not ret:
+        filelist, saveFilter = PyMcaFileDialogs.getFileList( \
+                    parent=self.maskImageWidget,
+                    filetypelist=formatlist,
+                    message="",
+                    currentdir=initdir,
+                    mode="SAVE",
+                    getfilter=True,
+                    single=False,
+                    currentfilter=None,
+                    native=None)
+        if not len(filelist):
             return "", ""
-        filename = filedialog.selectedFiles()[0]
+        filename = filelist[0]
         if filename:
-            filename = qt.safe_str(filename)
             self.outputDir = os.path.dirname(filename)
-            if hasattr(filedialog, "selectedFilter"):
-                saveFilter = qt.safe_str(filedialog.selectedFilter())
-            else:
-                saveFilter = qt.safe_str(filedialog.selectedNameFilter())
             filterused = "." + saveFilter[-3:]
             PyMcaDirs.outputDir = os.path.dirname(filename)
             if len(filename) < 4 or filename[-4:] != filterused:
@@ -312,7 +314,6 @@ class SaveImageListAction(qt.QAction):
             filename = ""
         return filename, saveFilter
 
-
 class SaveMatplotlib(qt.QAction):
     """Save current image ho high quality graphics using matplotlib"""
     def __init__(self, title, maskImageWidget):
@@ -475,6 +476,14 @@ class SilxMaskImageWidget(qt.QMainWindow):
 
         layout.addWidget(self.plot)
 
+        try:
+            from silx.gui.widgets import ElidedLabel
+            self.infoWidget = ElidedLabel.ElidedLabel(self)
+        except Exception:
+            self.infoWidget = qt.QLabel(self)
+        layout.addWidget(self.infoWidget)
+        self.infoWidget.hide()
+
         # Mask Widget
         self._maskToolsDockWidget = None
 
@@ -516,6 +525,7 @@ class SilxMaskImageWidget(qt.QMainWindow):
         self.replaceImageButton.clicked.connect(self._replaceImageClicked)
 
         layout.addWidget(buttonBox)
+        self._buttonBox = buttonBox
 
         # median filter widget
         self._medianParameters = {'row_width': 1,
@@ -596,8 +606,8 @@ class SilxMaskImageWidget(qt.QMainWindow):
         # Creating the toolbar also create actions for toolbuttons
         self._toolbar = self._createToolBar(title='Plot', parent=None)
         self.addToolBar(self._toolbar)
-
-        self._profile = ProfileToolBar(plot=self.plot)
+        self._profile = ProfileToolBar(plot=self.plot,
+                                       profileWindow=MyProfileWindow())
         self.addToolBar(self._profile)
         self.setProfileToolbarVisible(False)
 
@@ -696,8 +706,16 @@ class SilxMaskImageWidget(qt.QMainWindow):
             # self._maskToolsDockWidget.setFloating(True)
             self._maskToolsDockWidget.sigMaskChanged.connect(
                     self._emitMaskImageWidgetSignal)
+            # At the very least silx 1.1.0 was not restoring the plot mode prior
+            # to activate the mask. Force zoom state when closing the mask dock widget
+            self._maskToolsDockWidget.visibilityChanged[bool].connect(
+                    self._maskToolsDockWidgetVisibilityChanged)
         return self._maskToolsDockWidget
 
+    def _maskToolsDockWidgetVisibilityChanged(self, visibility):
+        if not visibility:
+            self.plot.setInteractiveMode("zoom")
+
     def _setMedianKernelWidth(self, value):
         kernelSize = numpy.asarray(value)
         if len(kernelSize.shape) == 0:
@@ -795,6 +813,16 @@ class SilxMaskImageWidget(qt.QMainWindow):
         """
         self.bgAction.setVisible(visible)
 
+    def setButtonBoxWidgetVisible(self, visible):
+        """Set visibility of the image actions widget
+
+        :param visible: True to show the buttons, False to hide them.
+        """
+        if visible:
+            self._buttonBox.show()
+        else:
+            self._buttonBox.hide()
+
     def setProfileToolbarVisible(self, visible):
         """Set visibility of the profile toolbar
 
@@ -1062,6 +1090,47 @@ class SilxMaskImageWidget(qt.QMainWindow):
         #     self._maskParamsCache = _maskParamsCache
         #     self.resetMask(width, height, self._origin, self._deltaXY)
 
+    def setImageData(self, data, clearmask=False, xScale=None, yScale=None):
+        """ Compatibility method with PyMca when handling single images
+        """
+        if xScale is None:
+            xScale = [0.0, 1.0]
+        if yScale is None:
+            yScale = [0.0, 1.0]
+        self._origin = (xScale[0], yScale[0])
+        self._deltaXY = (xScale[1], yScale[1])
+        info = None
+        if 0:
+            self.plot.addImage(data,
+                               legend="current",
+                               origin=self._origin,
+                               scale=self._deltaXY,
+                               replace=False,
+                               z=0,
+                               info=info)
+            self.plot.setActiveImage("current")
+            self.slider.setValue(0)
+        else:
+            self.setImages([data],
+                       labels=[""],
+                       origin=self._origin,
+                       width=xScale[1] * data.shape[1],
+                       height=yScale[1]* data.shape[0])
+
+    def plotImage(self, update=True):
+        """ Compatibility method with PyMca when handling single images
+        """
+        pass
+
+    def showInfo(self):
+        if self.infoWidget.isHidden():
+            self.infoWidget.show()
+
+    def setInfoText(self, text):
+        """ Compatibility method with PyMca when handling single images
+        """
+        self.infoWidget.setText(text)
+
     def _updateBgScales(self, heights, widths):
         """Recalculate BG scales
         (e.g after a crop operation on :attr:`_bg_images`)"""
@@ -1160,6 +1229,7 @@ class SilxMaskImageWidget(qt.QMainWindow):
 if __name__ == "__main__":
     app = qt.QApplication([])
     w = SilxMaskImageWidget()
+    w.setProfileToolbarVisible(True)
     w.show()
-    w.plot.addImage([[0, 1, 2], [2, 1, -1]])
+    w.setImages([numpy.array([[0, 1, 2], [2, 1, -1]])])
     app.exec()
