@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #/*##########################################################################
-# Copyright (C) 2004-2022 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2023 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
 # the ESRF.
@@ -43,6 +43,11 @@ except ImportError:
     from collections import MutableMapping
 
 from PyMca5.PyMcaGui import PyMcaQt as qt
+if sys.platform.startswith("darwin"):
+    import threading
+    QThread =  threading.Thread
+else:
+    QThread = qt.QThread
 
 QTVERSION = qt.qVersion()
 try:
@@ -209,6 +214,10 @@ def toolInfo():
     :returns 2-tuple: rootdir(str): directory of executables or GUI launch scripts
                         frozen(bool): run as frozen executable
     """
+    if getattr(sys, "frozen", False):
+        # frozen
+        rootdir = os.path.dirname(sys.executable)
+        return rootdir, True
     try:
         rootdir = os.path.dirname(__file__)
         if sys.platform == 'darwin':
@@ -219,7 +228,7 @@ def toolInfo():
         if not os.path.exists(os.path.join(rootdir, "PyMcaBatch.py")):
             # script usage case
             rootdir = os.path.dirname(EdfFileSimpleViewer.__file__)
-    except:
+    except Exception:
         # __file__ is not defined
         frozen = True
         rootdir = os.path.dirname(EdfFileSimpleViewer.__file__)
@@ -237,7 +246,9 @@ def toolInfo():
         rootdir = os.path.dirname(rootdir)
         # level PyMca5
         rootdir = os.path.dirname(rootdir)
-        # directory level with executables
+        # rootdir is the directory level with executables
+        # the above is not true with cx_Freeze because there is an additional
+        # /lib directory
     return rootdir, frozen
 
 
@@ -277,8 +288,9 @@ def launchThread(thread, window):
         window.close()
         thread.pleasePause = 0
         thread.pleaseBreak = 1
-        thread.quit()
-        thread.wait()
+        if hasattr(thread, "quit"):
+            thread.quit()
+            thread.wait()
         app = qt.QApplication.instance()
         app.processEvents()
     def pause():
@@ -1097,7 +1109,7 @@ class McaBatchGUI(qt.QWidget):
                             qt.QMessageBox.critical(self,"ERROR", msg)
                             self.raise_()
                             return False
-                except:
+                except Exception:
                     _logger.warning("Cannot verify suitability of output directory")
         return True
 
@@ -1110,14 +1122,14 @@ class McaBatchGUI(qt.QWidget):
                 fileinfo = ffile.GetSourceInfo()
                 if fileinfo['KeyList'] == []:ffile=None
                 return "EdfFile"
-            except:
+            except Exception:
                 pass
             if (ffile is None):
                 ffile = SpecFileLayer.SpecFileLayer()
                 ffile.SetSource(inputfile)
             del ffile
             return "Specfile"
-        except:
+        except Exception:
             qt.QMessageBox.critical(self,
                                     sys.exc_info()[0],
                                     'I do not know what to do with file\n %s' % ffile)
@@ -1130,7 +1142,7 @@ class McaBatchGUI(qt.QWidget):
             self.inputDir =  os.getcwd()
         wdir = self.inputDir
         wfilter = self.inputFilter
-        filetypes = "McaFiles (*.mca)\nEdfFiles (*.edf)\n"
+        filetypes = "McaFiles (*.mca)\nEdfFiles (*.edf)\nCSV (*.csv *.CSV)\n"
         if HDF5SUPPORT:
             filetypes += "HDF5 (*.nxs *.h5 *.hdf *.hdf5)\n"
         filetypes += "SpecFiles (*.spec)\nSpecFiles (*.dat)\nAll files (*)"
@@ -1157,7 +1169,8 @@ class McaBatchGUI(qt.QWidget):
         fileList = ConfigurationFileDialogs.getFitConfigurationFilePath(self,
                                                 currentdir=wdir,
                                                 mode="OPEN",
-                                                single=True)
+                                                single=True,
+                                                currentfilter="Fit configuration files (*.cfg)")
 
         if fileList:
             self.setConfigFile(fileList[0])
@@ -1466,7 +1479,7 @@ class McaBatchGUI(qt.QWidget):
         if os.path.exists(listfile):
             try:
                 os.remove(listfile)
-            except:
+            except Exception:
                 _logger.error("Cannot delete file %s", listfile)
                 raise
         if config is None:
@@ -1506,7 +1519,7 @@ class McaBatchGUI(qt.QWidget):
         if self._showResult:
             try:
                 self._showProcessResults(edfoutlist, datoutlist)
-            except:
+            except Exception:
                 _logger.error("Failed plotting result (probably interrupted by the user)")
 
     def _mergeProcessResults(self):
@@ -1551,15 +1564,14 @@ class McaBatchGUI(qt.QWidget):
             cmd = '%s "%s"' % (self._datviewer_path, datoutlist[0])
             launchProcess(cmd, independent=True)
 
-
-class McaBatch(McaAdvancedFitBatch.McaAdvancedFitBatch, qt.QThread):
+class McaBatch(McaAdvancedFitBatch.McaAdvancedFitBatch, QThread):
     """
     Batch fitting thread
     """
 
     def __init__(self, parent, configfile, **kwargs):
         McaAdvancedFitBatch.McaAdvancedFitBatch.__init__(self, configfile, **kwargs)
-        qt.QThread.__init__(self)
+        QThread.__init__(self)
         self.parent = parent
         self.pleasePause = 0
 
@@ -1574,18 +1586,13 @@ class McaBatch(McaAdvancedFitBatch.McaAdvancedFitBatch, qt.QThread):
                  'filebeginoffset':self.fileBeginOffset,
                  'fileendoffset':self.fileEndOffset,
                  'event':'onNewFile'}
-        if QTVERSION < '4.0.0':
-            self.postEvent(self.parent, McaCustomEvent.McaCustomEvent(ddict))
-        else:
-            qt.QApplication.postEvent(self.parent, McaCustomEvent.McaCustomEvent(ddict))
-        if self.pleasePause:self.__pauseMethod()
+        qt.QApplication.postEvent(self.parent, McaCustomEvent.McaCustomEvent(ddict))
+        if self.pleasePause:
+            self.__pauseMethod()
 
     def onImage(self, key, keylist):
         ddict = {'key':key, 'keylist':keylist, 'event':'onImage'}
-        if QTVERSION < '4.0.0':
-            self.postEvent(self.parent, McaCustomEvent.McaCustomEvent(ddict))
-        else:
-            qt.QApplication.postEvent(self.parent, McaCustomEvent.McaCustomEvent(ddict))
+        qt.QApplication.postEvent(self.parent, McaCustomEvent.McaCustomEvent(ddict))
 
     def onMca(self, imca, nmca, filename=None, key=None, info=None):
         _logger.debug("onMca key = %s", key)
@@ -1599,11 +1606,9 @@ class McaBatch(McaAdvancedFitBatch.McaAdvancedFitBatch, qt.QThread):
                  'useExistingFiles':self.useExistingFiles,
                  'roifit':self.roiFit,
                  'event':'onMca'}
-        if QTVERSION < '4.0.0':
-            self.postEvent(self.parent, McaCustomEvent.McaCustomEvent(ddict))
-        else:
-            qt.QApplication.postEvent(self.parent, McaCustomEvent.McaCustomEvent(ddict))
-        if self.pleasePause:self.__pauseMethod()
+        qt.QApplication.postEvent(self.parent, McaCustomEvent.McaCustomEvent(ddict))
+        if self.pleasePause:
+            self.__pauseMethod()
 
     def onEnd(self):
         _logger.debug("onEnd")
@@ -1754,7 +1759,7 @@ class McaBatchWindow(qt.QWidget):
                 if os.path.exists(self.htmlindex):
                     try:
                         os.remove(self.htmlindex)
-                    except:
+                    except Exception:
                         _logger.warning("cannot delete file %s", self.htmlindex)
         nfiles = len(indexlist)
         self.status.setText("Processing file %s" % file)
@@ -1814,7 +1819,7 @@ class McaBatchWindow(qt.QWidget):
                     else:
                         self.__htmlReport(filename, key, outputdir,
                                           useExistingFiles, info, firstmca = False)
-            except:
+            except Exception:
                 _logger.warning("ERROR on REPORT %s", sys.exc_info())
                 _logger.warning("%s", sys.exc_info()[1])
                 _logger.warning("filename = %s key =%s " , filename, key)
@@ -1843,14 +1848,14 @@ class McaBatchWindow(qt.QWidget):
         if not os.path.exists(fitdir):
             try:
                 os.makedirs(fitdir)
-            except:
+            except Exception:
                 _logger.warning("I could not create directory %s", fitdir)
                 return
         fitdir = os.path.join(fitdir, filename+"_HTMLDIR")
         if not os.path.exists(fitdir):
             try:
                 os.makedirs(fitdir)
-            except:
+            except Exception:
                 _logger.warning("I could not create directory %s", fitdir)
                 return
         localindex = os.path.join(fitdir, "index.html")
@@ -1864,7 +1869,7 @@ class McaBatchWindow(qt.QWidget):
             if not useExistingFiles:
                 try:
                     os.remove(outfile)
-                except:
+                except Exception:
                     _logger.warning("cannot delete file %s", outfile)
                 useExistingResult = 0
         else:
@@ -1886,7 +1891,7 @@ class McaBatchWindow(qt.QWidget):
                 #code removed, concentrations in McaAdvancedFitBatch.py
                 try:
                     os.remove(self._concentrationsFile)
-                except:
+                except Exception:
                     pass
                 """
                 pass
@@ -2168,7 +2173,7 @@ def main():
                               mcaoffset=mcaoffset, chunk=chunk, selection=selection,
                               diagnostics=diagnostics, multipage=multipage,
                               tif=tif, edf=edf, csv=csv, h5=h5, dat=dat)
-        except:
+        except Exception:
             if exitonend:
                 _logger.warning("Error: ", sys.exc_info()[1])
                 _logger.warning("Quitting as requested")
