@@ -1,8 +1,8 @@
 #/*##########################################################################
-# Copyright (C) 2004-2020 V.A. Sole, European Synchrotron Radiation Facility
+# Copyright (C) 2004-2023 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -23,7 +23,7 @@
 # THE SOFTWARE.
 #
 #############################################################################*/
-__author__ = "V.A. Sole - ESRF Data Analysis"
+__author__ = "V.A. Sole - ESRF"
 __contact__ = "sole@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
@@ -34,7 +34,7 @@ from . import RGBImageCalculator
 qt = RGBImageCalculator.qt
 QTVERSION = qt.qVersion()
 from . import RGBCorrelator
-from PyMca5.PyMcaGui import FrameBrowser
+from PyMca5.PyMcaGui.misc import FrameBrowser
 USE_BROWSER = True
 
 _logger = logging.getLogger(__name__)
@@ -44,11 +44,13 @@ class PyMcaImageWindow(RGBImageCalculator.RGBImageCalculator):
     def __init__(self, parent = None,
                  name = "PyMca Image Window",
                  correlator = None,
-                 scanwindow=None):
+                 scanwindow=None,
+                 usesilx=False):
         RGBImageCalculator.RGBImageCalculator.__init__(self, parent,
                                                        math = False,
                                                        replace = True,
-                                                       scanwindow=scanwindow)
+                                                       scanwindow=scanwindow,
+                                                       usesilx=usesilx)
         self.setWindowTitle(name)
         self.correlator = correlator
         self.ownCorrelator = False
@@ -438,11 +440,11 @@ if __name__ == "__main__":
     else:PYMCA = False
 
     if PYMCA:
-        from PyMca5.PyMcaGui import PyMcaMain
+        from PyMca5.PyMcaGui.pymca import PyMcaMain
         w = PyMcaMain.PyMcaMain()
         w.show()
     else:
-        w = PyMcaImageWindow()
+        w = PyMcaImageWindow(usesilx=None)
         w.show()
     counter = 0
     def function(period = period):
