@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #/*##########################################################################
-# Copyright (C) 2004-2022 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2023 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
 # the ESRF.
@@ -85,8 +85,8 @@ if __name__ == '__main__':
             else:
                 nativeFileDialogs = False
         elif opt in ('--PySide'):
-            print("Please use --binding=PySide")
-            import PySide.QtCore
+            print("Please use --binding=PySide6")
+            import PySide6.QtCore
         elif opt in ('--binding'):
             binding = arg.lower()
             if binding == "pyqt5":
@@ -95,6 +95,8 @@ if __name__ == '__main__':
                 import PySide2.QtCore
             elif binding == "pyside6":
                 import PySide6.QtCore
+            elif binding == "pyqt6":
+                import PyQt6.QtCore
             else:
                 raise ValueError("Unknown Qt binding <%s>" % binding)
 
@@ -119,10 +121,11 @@ if __name__ == '__main__':
     try:
         # make sure hdf5plugins are imported
         import hdf5plugin
-    except:
+    except Exception:
         _logger.info("Failed to import hdf5plugin")
 
 from PyMca5.PyMcaGui import PyMcaQt as qt
+from PyMca5.PyMcaGui.io import PyMcaFileDialogs
 QTVERSION = qt.qVersion()
 if sys.platform == 'darwin':
     if backend is not None:
@@ -134,7 +137,7 @@ try:
     # try to import silx prior to importing matplotlib to prevent
     # unnecessary warning
     import silx.gui.plot
-except:
+except Exception:
     pass
 from PyMca5.PyMcaGui.pymca import PyMcaMdi
 IconDict = PyMcaMdi.IconDict
@@ -147,13 +150,13 @@ else:
 try:
     from PyMca5.PyMcaGui.physics.xrf import XRFMCPyMca
     XRFMC_FLAG = True
-except:
+except Exception:
     XRFMC_FLAG = False
 
 try:
     from PyMca5.PyMcaGui.pymca import SumRulesTool
     SUMRULES_FLAG = True
-except:
+except Exception:
     SUMRULES_FLAG = False
 
 # prefer lazy import to avoid OpenCL related crashes on startup
@@ -201,7 +204,7 @@ if __name__ == "__main__":
         splash.showMessage( 'PyMca %s' % __version__,
                 alignment,
                 qt.Qt.white)
-    except:
+    except Exception:
         # fall back to original implementation in case of troubles
         splash.showMessage( 'PyMca %s' % __version__,
                 qt.Qt.AlignLeft|qt.Qt.AlignBottom,
@@ -228,7 +231,7 @@ try:
        ("PySide2.QtOpenGL") in sys.modules or \
        ("PyQt5.QtOpenGL") in sys.modules:
         OBJECT3D = True
-except:
+except Exception:
     _logger.info("pyopengl not installed")
     OBJECT3D = False
 
@@ -246,7 +249,7 @@ else:
 
 try:
     from PyMca5.PyMcaGui.pymca import SilxScatterWindow
-except:
+except Exception:
     _logger.info("Cannot import SilxScatterWindow")
 
 # check that OpenGL is actually supported (ESRF rnice problems)
@@ -271,7 +274,7 @@ if sys.platform.startswith("linux"):
                     _logger.info("OpenGL >= 1.4 not available")
                     OPENGL_DRIVERS_OK = False
                     OBJECT3D = False
-        except:
+        except Exception:
             _logger.info("Cannot test OpenGL availability %s" % sys.exc_info()[1])
 
 # PyMca 3D disabled in favor of silx
@@ -288,7 +291,7 @@ try:
     from PyMca5.PyMcaGui.pymca import QStackWidget
     from PyMca5.PyMcaGui.pymca import StackSelector
     STACK = True
-except:
+except Exception:
     STACK = False
 from PyMca5.PyMcaGui.pymca import PyMcaPostBatch
 from PyMca5.PyMcaGui.pymca import RGBCorrelator
@@ -302,7 +305,7 @@ if QTVERSION > '4.3.0':
     try:
         from PyMca5.PyMcaCore import XiaCorrect
         XIA_CORRECT = True
-    except:
+    except Exception:
         pass
 
 SOURCESLIST = QDispatcher.QDataSource.source_types.keys()
@@ -407,7 +410,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
             try:
                 defaultFileName = PyMca5.getDefaultSettingsFile()
                 self.configDir  = os.path.dirname(defaultFileName)
-            except:
+            except Exception:
                 if not ('fresh' in kw):
                     raise
             if not ('fresh' in kw):
@@ -523,7 +526,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
 
         try:
             self._dispatcherAddSelectionSlot(ddict)
-        except:
+        except Exception:
             if _logger.getEffectiveLevel() == logging.DEBUG:
                 raise
             msg = qt.QMessageBox(self)
@@ -589,7 +592,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
                         if ('tth' in motor_mne) and ('th' in motor_mne):
                             #FOURC
                             hkl = True
-                except:
+                except Exception:
                     pass
                 if hkl:
                     imageWindow = PyMcaHKLImageWindow.PyMcaHKLImageWindow(
@@ -600,7 +603,8 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
                     imageWindow = PyMcaImageWindow.PyMcaImageWindow(
                             name=legend,
                             correlator=self.imageWindowCorrelator,
-                            scanwindow=self.scanWindow)
+                            scanwindow=self.scanWindow,
+                            usesilx=None)
                 self.imageWindowDict[legend] = imageWindow
 
                 imageWindow.sigAddImageClicked.connect( \
@@ -654,7 +658,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
     def dispatcherRemoveSelectionSlot(self, ddict):
         try:
             return self._dispatcherRemoveSelectionSlot(ddict)
-        except:
+        except Exception:
             msg = qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Critical)
             txt = "Error: %s" % sys.exc_info()[1]
@@ -687,7 +691,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
     def dispatcherReplaceSelectionSlot(self, ddict):
         try:
             return self._dispatcherReplaceSelectionSlot(ddict)
-        except:
+        except Exception:
             msg = qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Critical)
             txt = "Error: %s" % sys.exc_info()[1]
@@ -865,7 +869,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
         try:
             d['ScanSimpleFit']['Configuration'].update(
                 self.scanWindow.scanFit.getConfiguration())
-        except:
+        except Exception:
             if _logger.getEffectiveLevel() == logging.DEBUG:
                 raise
             _logger.warning("Error getting ScanFit configuration")
@@ -926,6 +930,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
                         try:
                             PyMcaDirs.inputDir = ddict[source] ['lastInputDir']
                         except ValueError:
+                            _logger.info("Cannot open directory <%s>" % ddict[source] ['lastInputDir'])
                             pass
                 if 'SourceName' in ddict[source]:
                     if type(ddict[source]['SourceName']) != type([]):
@@ -951,7 +956,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
                                     self.sourceWidget.selectorWidget[source].openFile(SourceName, justloaded=1)
                                 else:
                                     self.sourceWidget.selectorWidget[source].openFile(SourceName)
-                            except:
+                            except Exception:
                                 msg = qt.QMessageBox(self)
                                 msg.setIcon(qt.QMessageBox.Critical)
                                 txt = "Error: %s\n opening file %s" % (sys.exc_info()[1],SourceName )
@@ -964,7 +969,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
                     if hasattr(selectorWidget,'setWidgetConfiguration'):
                         try:
                             selectorWidget.setWidgetConfiguration(ddict[source]['WidgetConfiguration'])
-                        except:
+                        except Exception:
                             msg = qt.QMessageBox(self)
                             msg.setIcon(qt.QMessageBox.Critical)
                             txt = "Error: %s\n configuring %s widget" % (sys.exc_info()[1], source )
@@ -1010,7 +1015,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
                     if d['LastFit']['fitdone']:
                         try:
                             self.mcaWindow.advancedfit.fit()
-                        except:
+                        except Exception:
                             pass
                 else:
                     print("hidden")
@@ -1035,7 +1040,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
                     if d['LastFit']['fitdone']:
                         try:
                             self.mcaWindow.advancedfit.fit()
-                        except:
+                        except Exception:
                             pass
                 else:
                     _logger.info("hidden")
@@ -1054,21 +1059,21 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
             self.actionOpen = qt.QAction(self)
             self.actionOpen.setText(QString("&Open"))
             self.actionOpen.setIcon(self.Icons["fileopen"])
-            self.actionOpen.setShortcut(qt.QKeySequence(qt.Qt.CTRL+qt.Qt.Key_O))
+            self.actionOpen.setShortcut(qt.QKeySequence(qt.Qt.CTRL|qt.Qt.Key_O))
             self.actionOpen.triggered[bool].connect(self.onOpen)
             #filesaveas
             self.actionSaveAs = qt.QAction(self)
             self.actionSaveAs.setText(QString("&Save"))
             self.actionSaveAs.setIcon(self.Icons["filesave"])
             self.actionSaveAs.setShortcut(\
-                qt.QKeySequence(qt.Qt.CTRL+qt.Qt.Key_S))
+                qt.QKeySequence(qt.Qt.CTRL|qt.Qt.Key_S))
             self.actionSaveAs.triggered[bool].connect(self.onSaveAs)
 
             #filesave
             self.actionSave = qt.QAction(self)
             self.actionSave.setText(QString("Save &Default Settings"))
             #self.actionSave.setIcon(self.Icons["filesave"])
-            #self.actionSave.setShortcut(qt.Qt.CTRL+qt.Qt.Key_S)
+            #self.actionSave.setShortcut(qt.Qt.CTRL|qt.Qt.Key_S)
             self.actionSave.triggered[bool].connect(self.onSave)
 
             #fileprint
@@ -1076,7 +1081,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
             self.actionPrint.setText(QString("&Print"))
             self.actionPrint.setIcon(self.Icons["fileprint"])
             self.actionPrint.setShortcut(\
-                qt.QKeySequence(qt.Qt.CTRL+qt.Qt.Key_P))
+                qt.QKeySequence(qt.Qt.CTRL|qt.Qt.Key_P))
             self.actionPrint.triggered[bool].connect(self.onPrint)
 
             #filequit
@@ -1084,7 +1089,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
             self.actionQuit.setText(QString("&Quit"))
             #self.actionQuit.setIcon(self.Icons["fileprint"])
             self.actionQuit.setShortcut(\
-                                       qt.QKeySequence(qt.Qt.CTRL+qt.Qt.Key_Q))
+                                       qt.QKeySequence(qt.Qt.CTRL|qt.Qt.Key_Q))
             qApp = qt.QApplication.instance()
             self.actionQuit.triggered.connect(qApp.closeAllWindows)
 
@@ -1122,6 +1127,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
             self.menuHelp.addAction("MCA &HOWTOs",self.onMcaHowto)
             self.menuHelp.addSeparator()
             self.menuHelp.addAction("&About", self.onAbout)
+            self.menuHelp.addAction("Web Documentation", self.onWebDocumentation)
             self.menuHelp.addAction("Changes", self.onChanges)
             self.menuHelp.addAction("About &Qt",self.onAboutQt)
             self.menuBar().addSeparator()
@@ -1175,7 +1181,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
         else:
             try:
                 self.splitter.insertWidget(0, self.sourceFrame)
-            except:
+            except Exception:
                 self.sourceFrame.setParent(self.splitter)
 
     def initSource(self):
@@ -1360,69 +1366,13 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
         wdir = PyMcaDirs.inputDir
         fileTypeList = typelist
         filterused = None
-        if False and PyMcaDirs.nativeFileDialogs:
-            #windows cannot handle thousands of files in a file dialog
-            filetypes = ""
-            for filetype in fileTypeList:
-                filetypes += filetype+"\n"
-            filelist = qt.QFileDialog.getOpenFileNames(self,
-                        message,
-                        wdir,
-                        filetypes)
-            if not len(filelist):
-                if getfilter:
-                    return [], filterused
-                else:
-                    return []
-            else:
-                sample  = qt.safe_str(filelist[0])
-                for filetype in fileTypeList:
-                    ftype = filetype.replace("(", "").replace(")","")
-                    extensions = ftype.split()[2:]
-                    for extension in extensions:
-                        if sample.endswith(extension[-3:]):
-                            filterused = filetype
-                            break
-        else:
-            fdialog = qt.QFileDialog(self)
-            fdialog.setModal(True)
-            fdialog.setWindowTitle(message)
-            if hasattr(qt, "QStringList"):
-                strlist = qt.QStringList()
-            else:
-                strlist = []
-            for filetype in fileTypeList:
-                strlist.append(filetype.replace("(","").replace(")",""))
-            if hasattr(fdialog, "setFilters"):
-                fdialog.setFilters(strlist)
-            else:
-                fdialog.setNameFilters(strlist)
-            fdialog.setFileMode(fdialog.ExistingFiles)
-            fdialog.setDirectory(wdir)
-            if QTVERSION > '4.3.0':
-                history = fdialog.history()
-                if len(history) > 6:
-                    fdialog.setHistory(history[-6:])
-            ret = fdialog.exec()
-            if ret == qt.QDialog.Accepted:
-                filelist = fdialog.selectedFiles()
-                if getfilter:
-                    filterused = qt.safe_str(fdialog.selectedFilter())
-                fdialog.close()
-                del fdialog
-            else:
-                fdialog.close()
-                del fdialog
-                if getfilter:
-                    return [], filterused
-                else:
-                    return []
-        filelist = [qt.safe_str(x) for x in filelist]
+        #windows cannot handle thousands of files in a file dialog force Qt dialogs
+        output = PyMcaFileDialogs.getFileList(self, filetypelist=typelist, message=message, currentdir=wdir,
+                                        mode="OPEN", getfilter=getfilter, single=False, currentfilter=None, native=False)
         if getfilter:
-            return filelist, filterused
+            return output[0], output[1]
         else:
-            return filelist
-
+            return output
 
     def __roiImaging(self):
         if self.__imagingTool is None:
@@ -1430,7 +1380,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
             try:
                 widget = QStackWidget.QStackWidget(mcawidget=self.mcaWindow,
                                                    rgbwidget=rgbWidget,
-                                                   master=True)
+                                                   primary=True)
                 widget.notifyCloseEventToWidget(self)
                 self.__imagingTool = id(widget)
                 self._widgetDict[self.__imagingTool] = widget
@@ -1449,7 +1399,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
                 msg.setDetailedText(traceback.format_exc())
                 msg.exec()
                 return
-            except:
+            except Exception:
                 widget = None
                 del self._widgetDict[self.__imagingTool]
                 self.__imagingTool = None
@@ -1487,7 +1437,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
                     if id(widget) != id(self):
                         if widget.parent() is None:
                             widget.close()
-                except:
+                except Exception:
                     _logger.debug("Error closing widget")
             from PyMca5.PyMcaGui.plotting import PyMcaPrintPreview
             PyMcaPrintPreview.resetSingletonPrintPreview()
@@ -1533,39 +1483,27 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
 
     def _onSaveAs(self):
         cwd = os.getcwd()
-        outfile = qt.QFileDialog(self)
-        if hasattr(outfile, "setFilters"):
-            outfile.setFilters(['PyMca  *.ini'])
-        else:
-            outfile.setNameFilters(['PyMca  *.ini'])
-        outfile.setFileMode(outfile.AnyFile)
-        outfile.setAcceptMode(qt.QFileDialog.AcceptSave)
-
         if os.path.exists(self.configDir):
-            cwd =self.configDir
-        outfile.setDirectory(cwd)
-        ret = outfile.exec()
-        if ret:
-            if hasattr(outfile, "selectedFilter"):
-                filterused = qt.safe_str(outfile.selectedFilter()).split()
-            else:
-                filterused = qt.safe_str(outfile.selectedNameFilter()).split()
-            extension = ".ini"
-            outdir=qt.safe_str(outfile.selectedFiles()[0])
-            try:
-                outputDir  = os.path.dirname(outdir)
-            except:
-                outputDir  = "."
-            try:
-                outputFile = os.path.basename(outdir)
-            except:
-                outputFile  = "PyMca.ini"
-            outfile.close()
-            del outfile
-        else:
-            outfile.close()
-            del outfile
+            cwd = self.configDir
+
+        outputFile = PyMcaFileDialogs.getFileList(self, filetypelist=['PyMca (*.ini)'],
+                                                message="Provide output file",
+                                                currentdir=cwd, mode="SAVE",
+                                                getfilter=False, single=False,
+                                                currentfilter=None, native=None)
+        if not len(outputFile):
             return
+        extension = ".ini"
+        outputFile = outputFile[0]
+        try:
+            outputDir  = os.path.dirname(outputFile)
+        except Exception:
+            outputDir  = "."
+        try:
+            outputFile = os.path.basename(outputFile)
+        except Exception:
+            outputFile  = "PyMca.ini"
+
         #always overwrite for the time being
         if len(outputFile) < len(extension[:]):
             outputFile += extension[:]
@@ -1586,7 +1524,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
         try:
             self._saveAs(filename)
             self.configDir = outputDir
-        except:
+        except Exception:
             msg = qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setText("Error Saving Configuration: %s" % (sys.exc_info()[1]))
@@ -1622,7 +1560,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
                     # but we change the input dir to allow easy loading of the config file from the
                     # fit configuration window
                     PyMcaDirs.inputDir = os.path.dirname(source)
-        except:
+        except Exception:
             msg = qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setWindowTitle("Error opening data source")
@@ -1637,24 +1575,22 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
     def openSource(self,index=0):
         _logger.debug("index = %d ", index)
         if index <= 0:
-            outfile = qt.QFileDialog(self)
-            outfile.setWindowTitle("Select PyMca Configuration File")
             if os.path.exists(self.configDir):
-                outfile.setDirectory(self.configDir)
-            if hasattr(outfile, "setFilters"):
-                outfile.setFilters(['PyMca  *.ini'])
+                currentdir = self.configDir
             else:
-                outfile.setNameFilters(['PyMca  *.ini'])
-            outfile.setFileMode(outfile.ExistingFile)
-            ret = outfile.exec()
-            if ret:
-                filename = qt.safe_str(outfile.selectedFiles()[0])
-                outfile.close()
-                del outfile
-            else:
-                outfile.close()
-                del outfile
+                currentdir = None
+            filename = PyMcaFileDialogs.getFileList(parent=self,
+                                                   filetypelist=['PyMca (*.ini)'],
+                                                   message="Select PyMca Configuration File",
+                                                   currentdir=currentdir,
+                                                   mode="OPEN",
+                                                   getfilter=False,
+                                                   single=False,
+                                                   currentfilter=None,
+                                                   native=None)
+            if not len(filename):
                 return
+            filename = filename[0]
             currentConfigDict = ConfigDict.ConfigDict()
             self.configDir  = os.path.dirname(filename)
             currentConfigDict.read(filename)
@@ -1723,6 +1659,11 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
                 "PyMca Application\nVersion: "+__version__)
         #self.onDebug()
 
+    def onWebDocumentation(self):
+        import webbrowser
+        url = "http://www.silx.org/doc/PyMca/dev/"
+        webbrowser.open(url)
+
     def onChanges(self):
         if self.changeLog is None:
             self.changeLog = qt.QTextEdit()
@@ -1759,7 +1700,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
                         _logger.debug("Module name = %s, %s",
                                       module.__name__,
                                       module.__revision__.replace("$", ""))
-            except:
+            except Exception:
                 pass
 
     def onPrint(self):
@@ -1836,7 +1777,7 @@ if 0:
             return "Graph %d"%(idx)
 
 class MyQTextBrowser(qt.QTextBrowser):
-    def setSource(self, name):
+    def myWrappedSource(self, name, ignored=None):
         if name == QString("./PyMCA.html") or ("PyMCA.html" in ("%s" % name)):
             if sys.platform == 'win32':
                 ddir=PyMcaDataDir.PYMCA_DOC_DIR
@@ -1847,7 +1788,7 @@ class MyQTextBrowser(qt.QTextBrowser):
                 return
             try:
                 self.report.show()
-            except:
+            except Exception:
                 self.report = qt.QTextBrowser()
                 self.report.setCaption(QString("PyMca Report"))
                 ddir=PyMcaDataDir.PYMCA_DOC_DIR
@@ -1858,7 +1799,17 @@ class MyQTextBrowser(qt.QTextBrowser):
                 self.report.show()
             self.report.raise_()
         else:
-            qt.QTextBrowser.setSource(self, name)
+            if QTVERSION.startswith('6'):
+                qt.QTextBrowser.doSetSource(self, name)
+            else:
+                qt.QTextBrowser.setSource(self, name)
+
+    if QTVERSION.startswith('6'):
+        def doSetSource(self, name, ignored=None):
+            return self.myWrappedSource(name, ignored)
+    else:
+        def setSource(self, name):
+            return self.myWrappedSource(name)
 
 class Line(qt.QFrame):
     sigLineDoubleClickEvent = qt.pyqtSignal(object)
@@ -1899,7 +1850,7 @@ if __name__ == '__main__':
     try:
         for source in args:
             PyMcaMainWidgetInstance.sourceWidget.sourceSelector.openSource(source)
-    except:
+    except Exception:
         msg = qt.QMessageBox(PyMcaMainWidgetInstance)
         msg.setIcon(qt.QMessageBox.Critical)
         msg.setWindowTitle("Error opening data source")
