@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #/*##########################################################################
-# Copyright (C) 2004-2022 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2023 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
 # the ESRF.
@@ -36,6 +36,7 @@ from io import StringIO
 import logging
 
 from PyMca5.PyMcaGui import PyMcaQt as qt
+from PyMca5.PyMcaGui.io import PyMcaFileDialogs
 from PyMca5.PyMcaCore import PyMcaMatplotlibSave
 from PyMca5.PyMcaGui.plotting.PyMca_Icons import IconDict
 from PyMca5.PyMcaGui.plotting import PyMcaPrintPreview
@@ -171,7 +172,7 @@ class SaveImageSetup(qt.QWidget):
         try:
             ddict = self.getParameters()
             self.imageWidget.setParameters(ddict)
-        except:
+        except Exception:
             msg = qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setText("Error updating image:")
@@ -187,7 +188,7 @@ class SaveImageSetup(qt.QWidget):
             if self.printPreview.isHidden():
                 self.printPreview.show()
             self.printPreview.raise_()
-        except:
+        except Exception:
             msg = qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setText("Error printing image: %s" % sys.exc_info()[1])
@@ -196,62 +197,38 @@ class SaveImageSetup(qt.QWidget):
 
 
     def saveClicked(self):
-        outfile = qt.QFileDialog(self)
-        outfile.setModal(1)
         if self.lastOutputDir is None:
             self.lastOutputDir = PyMcaDirs.outputDir
 
-        outfile.setWindowTitle("Output File Selection")
-        if hasattr(qt, "QStringList"):
-            strlist = qt.QStringList()
-        else:
-            strlist = []
         format_list = []
         format_list.append('Graphics PNG *.png')
         format_list.append('Graphics EPS *.eps')
         format_list.append('Graphics SVG *.svg')
-        for f in format_list:
-            strlist.append(f)
-        if hasattr(outfile, "setFilters"):
-            outfile.setFilters(strlist)
-        else:
-            outfile.setNameFilters(strlist)
-        outfile.setFileMode(outfile.AnyFile)
-        outfile.setAcceptMode(qt.QFileDialog.AcceptSave)
-        outfile.setDirectory(self.lastOutputDir)
-        ret = outfile.exec()
-        if ret:
-            if hasattr(outfile, "selectedFilter"):
-                filterused = qt.safe_str(outfile.selectedFilter()).split()
-            else:
-                filterused = qt.safe_str(outfile.selectedNameFilter()).split()
-            filedescription = filterused[0]
-            filetype  = filterused[1]
-            extension = filterused[2]
-            try:
-                outstr = qt.safe_str(outfile.selectedFiles()[0])
-            except:
-                msg = qt.QMessageBox(self)
-                msg.setIcon(qt.QMessageBox.Critical)
-                msg.setText("Error saving image: %s" % sys.exc_info()[1])
-                msg.setWindowTitle('Matplotlib Save Image')
-                msg.exec()
-            try:
-                outputDir  = os.path.dirname(outstr)
-                self.lastOutputDir = outputDir
-                PyMcaDirs.outputDir = outputDir
-            except:
-                outputDir  = "."
-            try:
-                outputFile = os.path.basename(outstr)
-            except:
-                outputFile  = outstr
-            outfile.close()
-            del outfile
-        else:
-            outfile.close()
-            del outfile
+        outputFile, filterused = PyMcaFileDialogs.getFileList(self, filetypelist=format_list,
+                                                              message="Output File Selection",
+                                                              currentdir=self.lastOutputDir,
+                                                              mode="SAVE", getfilter=True,
+                                                              single=False, currentfilter=None, native=None)
+        if not len(outputFile):
             return
+
+        filterused = filterused.split()
+        filedescription = filterused[0]
+        filetype  = filterused[1]
+        extension = filterused[2]
+
+        outputFile = outputFile[0]
+        try:
+            outputDir  = os.path.dirname(outputFile)
+            self.lastOutputDir = outputDir
+            PyMcaDirs.outputDir = outputDir
+        except Exception:
+            outputDir  = "."
+        try:
+            outputFile = os.path.basename(outputFile)
+        except Exception:
+            outputFile  = outputFile
+
         #always overwrite for the time being
         if len(outputFile) < len(extension[1:]):
             outputFile += extension[1:]
@@ -262,7 +239,7 @@ class SaveImageSetup(qt.QWidget):
         if os.path.exists(finalFile):
             try:
                 os.remove(finalFile)
-            except:
+            except Exception:
                 msg = qt.QMessageBox(self)
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("Cannot overwrite file: %s" % sys.exc_info()[1])
@@ -275,7 +252,7 @@ class SaveImageSetup(qt.QWidget):
                                           facecolor='w',
                                           format=finalFile[-3:],
                                           dpi=self.imageWidget.config['outputdpi'])
-        except:
+        except Exception:
             _logger.warning("trying to save using obsolete method")
             config = self.imageWidget.getParameters()
             try:
@@ -284,7 +261,7 @@ class SaveImageSetup(qt.QWidget):
                     s.setPixmapImage(self.imageWidget.pixmapImage)
                 s.setParameters(config)
                 s.saveImage(finalFile)
-            except:
+            except Exception:
                 msg = qt.QMessageBox(self)
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("Error saving file: %s" % sys.exc_info()[1])
@@ -500,14 +477,14 @@ class RightWidget(qt.QWidget):
                         try:
                             txt = ddict[label][0].upper() +\
                                   ddict[label][1:].lower()
-                        except:
+                        except Exception:
                             pass
                     self.comboBoxList[i].setCurrentText(txt)
         return
 
 class MyLineEdit(qt.QLineEdit):
     def sizeHint(self):
-        return qt.QSize(0.6 * qt.QLineEdit.sizeHint(self).width(),
+        return qt.QSize(int(0.6 * qt.QLineEdit.sizeHint(self).width()),
                         qt.QLineEdit.sizeHint(self).height())
 
 
@@ -802,7 +779,7 @@ class QPyMcaMatplotlibImage(FigureCanvas):
                         tick_locator = MaxNLocator(nTicks)
                         self._colorbar.locator = tick_locator
                         self._colorbar.update_ticks()
-                    except:
+                    except Exception:
                         _logger.warning("Colorbar error %s", sys.exc_info())
                         pass
             else:
