@@ -2,10 +2,10 @@
 #
 # The PyMca X-Ray Fluorescence Toolkit
 #
-# Copyright (c) 2004-2017 European Synchrotron Radiation Facility
+# Copyright (c) 2004-2023 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -26,7 +26,7 @@
 # THE SOFTWARE.
 #
 #############################################################################*/
-__author__ = "V.A. Sole - ESRF Data Analysis"
+__author__ = "V.A. Sole - ESRF"
 __contact__ = "sole@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
@@ -311,7 +311,7 @@ def isJcampFile(filename):
             else:
                 return False
         return True
-    except:
+    except Exception:
         return False
 
 if __name__ == "__main__":
@@ -329,5 +329,5 @@ if __name__ == "__main__":
         plt.xlabel(instance.info.get('XUNITS', 'X'))
         plt.ylabel(instance.info.get('YUNITS', 'Y'))
         plt.show()
-    except:
+    except Exception:
         pass
