@@ -1,8 +1,8 @@
 #/*##########################################################################
-# Copyright (C) 2004-2015 V.A. Sole, European Synchrotron Radiation Facility
+# Copyright (C) 2004-2023 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -23,7 +23,7 @@
 # THE SOFTWARE.
 #
 #############################################################################*/
-__author__ = "V.A. Sole - ESRF Data Analysis"
+__author__ = "V.A. Sole - ESRF"
 __contact__ = "sole@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
@@ -46,8 +46,8 @@ import os
 import logging
 import traceback
 from PyMca5 import StackPluginBase
-from PyMca5.PyMcaGui import CalculationThread
-# only EDGE and JUMP are always small enough to be shown ...
+from PyMca5.PyMcaGui.misc import CalculationThread
+# only EDGE and JUMP are always small enough to be shown
 from PyMca5.PyMcaGui import StackPluginResultsWindow
 from PyMca5.PyMcaGui import StackXASBatchWindow
 from PyMca5.PyMcaGui import PyMca_Icons as PyMca_Icons
@@ -150,16 +150,15 @@ class XASStackBatchPlugin(StackPluginBase.StackPluginBase):
             self.thread = CalculationThread.CalculationThread(\
                             calculation_method=self.actualCalculation)
             self.thread.result = self.actualCalculation()
-            self.threadFinished()
         else:
             self.thread = CalculationThread.CalculationThread(\
                             calculation_method=self.actualCalculation)
-            self.thread.finished.connect(self.threadFinished)
             self.thread.start()
             message = "Please wait. Calculation going on."
             CalculationThread.waitingMessageDialog(self.thread,
                                 parent=self.configurationWidget,
                                 message=message)
+        self.threadFinished()
 
     def actualCalculation(self):
         activeCurve = self.getActiveCurve()
@@ -197,7 +196,7 @@ class XASStackBatchPlugin(StackPluginBase.StackPluginBase):
     def threadFinished(self):
         try:
             self._threadFinished()
-        except:
+        except Exception:
             msg = qt.QMessageBox()
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setInformativeText(str(sys.exc_info()[1]))
