@@ -2,10 +2,10 @@
 #
 # The PyMca X-Ray Fluorescence Toolkit
 #
-# Copyright (c) 2004-2020 European Synchrotron Radiation Facility
+# Copyright (c) 2004-2023 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -26,7 +26,7 @@
 # THE SOFTWARE.
 #
 #############################################################################*/
-__author__ = "V. Armando Sole - ESRF Data Analysis"
+__author__ = "V. Armando Sole - ESRF"
 __contact__ = "sole@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
@@ -40,7 +40,7 @@ current_locale = locale.getlocale()
 for l in ['de_DE.utf8', 'fr_FR.utf8']:
     try:
         locale.setlocale(locale.LC_ALL, l)
-    except:
+    except Exception:
         other_locale = False
     else:
         other_locale = l
@@ -55,7 +55,7 @@ class testSpecfile(unittest.TestCase):
         try:
             from PyMca5.PyMcaIO import specfile
             self.specfileClass = specfile
-        except:
+        except Exception:
             self.specfileClass = None
         if self.specfileClass is not None:
             text  = "#F \n"
